@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\PasswordTagRelation;
@@ -17,19 +21,13 @@ use OCP\EventDispatcher\Event;
  */
 class GenericPasswordTagRelationEvent extends Event {
 
-    /**
-     * @var PasswordTagRelation
-     */
-    protected PasswordTagRelation $PasswordTagRelation;
-
     /**
      * GenericPasswordTagRelationEvent constructor.
      *
      * @param PasswordTagRelation $PasswordTagRelation
      */
-    public function __construct(PasswordTagRelation $PasswordTagRelation) {
+    public function __construct(protected PasswordTagRelation $PasswordTagRelation) {
         parent::__construct();
-        $this->PasswordTagRelation = $PasswordTagRelation;
     }
 
     /**
